@@ -1,27 +1,18 @@
 from collections import OrderedDict
 from copy import copy, deepcopy
-from typing import Dict, Any, Callable
+from typing import Optional
 
 from .source import ConfigSource
-from .types import PROFILE_GLOBAL
+from .types import ConfigDict, ConfigKey, ConfigValue
 from .utils import dict_merge, config_merger
 
 
 class ConfigSnippet(OrderedDict):
-    def __init__(self, config: Dict[str, Any], source: ConfigSource):
+    def __init__(self, config: ConfigDict, source: ConfigSource):
         super().__init__(config)
         self.source = source
 
-    @property
-    def profile(
-        self,
-        getter: Callable[["ConfigSnippet"], str] = lambda x: x.get(
-            "profile", PROFILE_GLOBAL
-        ),
-    ):
-        return getter(self)
-
-    def __add__(self, other: "ConfigSnippet"):
+    def __add__(self, other: "ConfigSnippet") -> "ConfigSnippet":
         if other is None:
             return copy(self)
 
@@ -30,16 +21,16 @@ class ConfigSnippet(OrderedDict):
             source=self.source + other.source,
         )
 
-    def __copy__(self):
+    def __copy__(self) -> "ConfigSnippet":
         return ConfigSnippet(
             config={k: copy(v) for k, v in self.items()}, source=self.source
         )
 
-    def __deepcopy__(self, memodict={}):
+    def __deepcopy__(self, memodict={}) -> "ConfigSnippet":
         return ConfigSnippet(
             config={k: deepcopy(v, memodict) for k, v in self.items()},
             source=self.source,
         )
 
-    def find(self, key):
+    def find(self, key: ConfigKey) -> Optional[ConfigValue]:
         return self.get(key, self.source.find(key))
